from .. import IconBase


class IconTriangleAlert(IconBase):
    class_name = "lucide lucide-triangle-alert"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3"
            }
        },
        {
            "path": {
                "d": "M12 9v4"
            }
        },
        {
            "path": {
                "d": "M12 17h.01"
            }
        }
    ]
}
