from .. import IconBase


class IconLampDesk(IconBase):
    class_name = "lucide lucide-lamp-desk"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m14 5-3 3 2 7 8-8-7-2Z"
            }
        },
        {
            "path": {
                "d": "m14 5-3 3-3-3 3-3 3 3Z"
            }
        },
        {
            "path": {
                "d": "M9.5 6.5 4 12l3 6"
            }
        },
        {
            "path": {
                "d": "M3 22v-2c0-1.1.9-2 2-2h4a2 2 0 0 1 2 2v2H3Z"
            }
        }
    ]
}
