from .. import IconBase


class IconPrinter(IconBase):
    class_name = "lucide lucide-printer"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polyline": {
                "points": "6 9 6 2 18 2 18 9"
            }
        },
        {
            "path": {
                "d": "M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2"
            }
        },
        {
            "rect": {
                "width": "12",
                "height": "8",
                "x": "6",
                "y": "14"
            }
        }
    ]
}
