from .. import IconBase


class IconMails(IconBase):
    class_name = "lucide lucide-mails"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "16",
                "height": "13",
                "x": "6",
                "y": "4",
                "rx": "2"
            }
        },
        {
            "path": {
                "d": "m22 7-7.1 3.78c-.57.3-1.23.3-1.8 0L6 7"
            }
        },
        {
            "path": {
                "d": "M2 8v11c0 1.1.9 2 2 2h14"
            }
        }
    ]
}
