from .. import IconBase


class IconCalendarX2(IconBase):
    class_name = "lucide lucide-calendar-x-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 2v4"
            }
        },
        {
            "path": {
                "d": "M16 2v4"
            }
        },
        {
            "path": {
                "d": "M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8"
            }
        },
        {
            "path": {
                "d": "M3 10h18"
            }
        },
        {
            "path": {
                "d": "m17 22 5-5"
            }
        },
        {
            "path": {
                "d": "m17 17 5 5"
            }
        }
    ]
}
