from .. import IconBase


class IconMouseOff(IconBase):
    class_name = "lucide lucide-mouse-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 6v.343"
            }
        },
        {
            "path": {
                "d": "M18.218 18.218A7 7 0 0 1 5 15V9a7 7 0 0 1 .782-3.218"
            }
        },
        {
            "path": {
                "d": "M19 13.343V9A7 7 0 0 0 8.56 2.902"
            }
        },
        {
            "path": {
                "d": "M22 22 2 2"
            }
        }
    ]
}
