from .. import IconBase


class IconMonitorDot(IconBase):
    class_name = "lucide lucide-monitor-dot"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "19",
                "cy": "6",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M22 12v3a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h9"
            }
        },
        {
            "path": {
                "d": "M12 17v4"
            }
        },
        {
            "path": {
                "d": "M8 21h8"
            }
        }
    ]
}
