from .. import IconBase


class IconUsersRound(IconBase):
    class_name = "lucide lucide-users-round"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 21a8 8 0 0 0-16 0"
            }
        },
        {
            "circle": {
                "cx": "10",
                "cy": "8",
                "r": "5"
            }
        },
        {
            "path": {
                "d": "M22 20c0-3.37-2-6.5-4-8a5 5 0 0 0-.45-8.3"
            }
        }
    ]
}
