from .. import IconBase


class IconHeading2(IconBase):
    class_name = "lucide lucide-heading-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 12h8"
            }
        },
        {
            "path": {
                "d": "M4 18V6"
            }
        },
        {
            "path": {
                "d": "M12 18V6"
            }
        },
        {
            "path": {
                "d": "M21 18h-4c0-4 4-3 4-6 0-1.5-2-2.5-4-1"
            }
        }
    ]
}
