from .. import IconBase


class IconSlice(IconBase):
    class_name = "lucide lucide-slice"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m8 14-6 6h9v-3"
            }
        },
        {
            "path": {
                "d": "M18.37 3.63 8 14l3 3L21.37 6.63a2.12 2.12 0 1 0-3-3Z"
            }
        }
    ]
}
