from .. import IconBase


class IconBotMessageSquare(IconBase):
    class_name = "lucide lucide-bot-message-square"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 6V2H8"
            }
        },
        {
            "path": {
                "d": "m8 18-4 4V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2Z"
            }
        },
        {
            "path": {
                "d": "M2 12h2"
            }
        },
        {
            "path": {
                "d": "M9 11v2"
            }
        },
        {
            "path": {
                "d": "M15 11v2"
            }
        },
        {
            "path": {
                "d": "M20 12h2"
            }
        }
    ]
}
