from .. import IconBase


class IconOctagonX(IconBase):
    class_name = "lucide lucide-octagon-x"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polygon": {
                "points": "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2"
            }
        },
        {
            "path": {
                "d": "m15 9-6 6"
            }
        },
        {
            "path": {
                "d": "m9 9 6 6"
            }
        }
    ]
}
