from .. import IconBase


class IconWrapText(IconBase):
    class_name = "lucide lucide-wrap-text"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "3",
                "x2": "21",
                "y1": "6",
                "y2": "6"
            }
        },
        {
            "path": {
                "d": "M3 12h15a3 3 0 1 1 0 6h-4"
            }
        },
        {
            "polyline": {
                "points": "16 16 14 18 16 20"
            }
        },
        {
            "line": {
                "x1": "3",
                "x2": "10",
                "y1": "18",
                "y2": "18"
            }
        }
    ]
}
