from .. import IconBase


class IconFolderPen(IconBase):
    class_name = "lucide lucide-folder-pen"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8.4 10.6a2 2 0 0 1 3 3L6 19l-4 1 1-4Z"
            }
        },
        {
            "path": {
                "d": "M2 11.5V5a2 2 0 0 1 2-2h3.9c.7 0 1.3.3 1.7.9l.8 1.2c.4.6 1 .9 1.7.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-9.5"
            }
        }
    ]
}
