from .. import IconBase


class IconMessageCircleX(IconBase):
    class_name = "lucide lucide-message-circle-x"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M7.9 20A9 9 0 1 0 4 16.1L2 22Z"
            }
        },
        {
            "path": {
                "d": "m15 9-6 6"
            }
        },
        {
            "path": {
                "d": "m9 9 6 6"
            }
        }
    ]
}
