from .. import IconBase


class IconWind(IconBase):
    class_name = "lucide lucide-wind"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M17.7 7.7a2.5 2.5 0 1 1 1.8 4.3H2"
            }
        },
        {
            "path": {
                "d": "M9.6 4.6A2 2 0 1 1 11 8H2"
            }
        },
        {
            "path": {
                "d": "M12.6 19.4A2 2 0 1 0 14 16H2"
            }
        }
    ]
}
