from .. import IconBase


class IconFileBadge(IconBase):
    class_name = "lucide lucide-file-badge"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22h6a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3"
            }
        },
        {
            "path": {
                "d": "M14 2v4a2 2 0 0 0 2 2h4"
            }
        },
        {
            "path": {
                "d": "M5 17a3 3 0 1 0 0-6 3 3 0 0 0 0 6Z"
            }
        },
        {
            "path": {
                "d": "M7 16.5 8 22l-3-1-3 1 1-5.5"
            }
        }
    ]
}
