from .. import IconBase


class IconFolderClock(IconBase):
    class_name = "lucide lucide-folder-clock"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "16",
                "cy": "16",
                "r": "6"
            }
        },
        {
            "path": {
                "d": "M7 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M16 14v2l1 1"
            }
        }
    ]
}
