from .. import IconBase


class IconRepeat2(IconBase):
    class_name = "lucide lucide-repeat-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m2 9 3-3 3 3"
            }
        },
        {
            "path": {
                "d": "M13 18H7a2 2 0 0 1-2-2V6"
            }
        },
        {
            "path": {
                "d": "m22 15-3 3-3-3"
            }
        },
        {
            "path": {
                "d": "M11 6h6a2 2 0 0 1 2 2v10"
            }
        }
    ]
}
