from .. import IconBase


class IconSatellite(IconBase):
    class_name = "lucide lucide-satellite"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 7 9 3 5 7l4 4"
            }
        },
        {
            "path": {
                "d": "m17 11 4 4-4 4-4-4"
            }
        },
        {
            "path": {
                "d": "m8 12 4 4 6-6-4-4Z"
            }
        },
        {
            "path": {
                "d": "m16 8 3-3"
            }
        },
        {
            "path": {
                "d": "M9 21a6 6 0 0 0-6-6"
            }
        }
    ]
}
