from .. import IconBase


class IconFlameKindling(IconBase):
    class_name = "lucide lucide-flame-kindling"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 2c1 3 2.5 3.5 3.5 4.5A5 5 0 0 1 17 10a5 5 0 1 1-10 0c0-.3 0-.6.1-.9a2 2 0 1 0 3.3-2C8 4.5 11 2 12 2Z"
            }
        },
        {
            "path": {
                "d": "m5 22 14-4"
            }
        },
        {
            "path": {
                "d": "m5 18 14 4"
            }
        }
    ]
}
