from .. import IconBase


class IconKeyRound(IconBase):
    class_name = "lucide lucide-key-round"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 18v3c0 .6.4 1 1 1h4v-3h3v-3h2l1.4-1.4a6.5 6.5 0 1 0-4-4Z"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        }
    ]
}
