from .. import IconBase


class IconScreenShareOff(IconBase):
    class_name = "lucide lucide-screen-share-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 3H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-3"
            }
        },
        {
            "path": {
                "d": "M8 21h8"
            }
        },
        {
            "path": {
                "d": "M12 17v4"
            }
        },
        {
            "path": {
                "d": "m22 3-5 5"
            }
        },
        {
            "path": {
                "d": "m17 3 5 5"
            }
        }
    ]
}
