from .. import IconBase


class IconBringToFront(IconBase):
    class_name = "lucide lucide-bring-to-front"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "x": "8",
                "y": "8",
                "width": "8",
                "height": "8",
                "rx": "2"
            }
        },
        {
            "path": {
                "d": "M4 10a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M14 20a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2"
            }
        }
    ]
}
