from .. import IconBase


class IconMerge(IconBase):
    class_name = "lucide lucide-merge"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m8 6 4-4 4 4"
            }
        },
        {
            "path": {
                "d": "M12 2v10.3a4 4 0 0 1-1.172 2.872L4 22"
            }
        },
        {
            "path": {
                "d": "m20 22-5-5"
            }
        }
    ]
}
