from .. import IconBase


class IconMessageSquareQuote(IconBase):
    class_name = "lucide lucide-message-square-quote"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"
            }
        },
        {
            "path": {
                "d": "M8 12a2 2 0 0 0 2-2V8H8"
            }
        },
        {
            "path": {
                "d": "M14 12a2 2 0 0 0 2-2V8h-2"
            }
        }
    ]
}
