from .. import IconBase


class IconCloudMoon(IconBase):
    class_name = "lucide lucide-cloud-moon"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 16a3 3 0 1 1 0 6H7a5 5 0 1 1 4.9-6Z"
            }
        },
        {
            "path": {
                "d": "M10.1 9A6 6 0 0 1 16 4a4.24 4.24 0 0 0 6 6 6 6 0 0 1-3 5.197"
            }
        }
    ]
}
