from .. import IconBase


class IconTerminal(IconBase):
    class_name = "lucide lucide-terminal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polyline": {
                "points": "4 17 10 11 4 5"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "20",
                "y1": "19",
                "y2": "19"
            }
        }
    ]
}
