from .. import IconBase


class IconTrash(IconBase):
    class_name = "lucide lucide-trash"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 6h18"
            }
        },
        {
            "path": {
                "d": "M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6"
            }
        },
        {
            "path": {
                "d": "M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2"
            }
        }
    ]
}
