from .. import IconBase


class IconLampWallUp(IconBase):
    class_name = "lucide lucide-lamp-wall-up"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M11 4h6l3 7H8l3-7Z"
            }
        },
        {
            "path": {
                "d": "M14 11v5a2 2 0 0 1-2 2H8"
            }
        },
        {
            "path": {
                "d": "M4 15h2a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H4v-6Z"
            }
        }
    ]
}
