from .. import IconBase


class IconBookLock(IconBase):
    class_name = "lucide lucide-book-lock"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H10"
            }
        },
        {
            "path": {
                "d": "M20 15v7H6.5a2.5 2.5 0 0 1 0-5H20"
            }
        },
        {
            "rect": {
                "width": "8",
                "height": "5",
                "x": "12",
                "y": "6",
                "rx": "1"
            }
        },
        {
            "path": {
                "d": "M18 6V4a2 2 0 1 0-4 0v2"
            }
        }
    ]
}
