from .. import IconBase


class IconPlugZap2(IconBase):
    class_name = "lucide lucide-plug-zap-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m13 2-2 2.5h3L12 7"
            }
        },
        {
            "path": {
                "d": "M10 14v-3"
            }
        },
        {
            "path": {
                "d": "M14 14v-3"
            }
        },
        {
            "path": {
                "d": "M11 19c-1.7 0-3-1.3-3-3v-2h8v2c0 1.7-1.3 3-3 3Z"
            }
        },
        {
            "path": {
                "d": "M12 22v-3"
            }
        }
    ]
}
