from .. import IconBase


class IconCoffee(IconBase):
    class_name = "lucide lucide-coffee"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 2v2"
            }
        },
        {
            "path": {
                "d": "M14 2v2"
            }
        },
        {
            "path": {
                "d": "M16 8a1 1 0 0 1 1 1v8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4V9a1 1 0 0 1 1-1h14a4 4 0 1 1 0 8h-1"
            }
        },
        {
            "path": {
                "d": "M6 2v2"
            }
        }
    ]
}
