from .. import IconBase


class IconCloudDownload(IconBase):
    class_name = "lucide lucide-cloud-download"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242"
            }
        },
        {
            "path": {
                "d": "M12 12v9"
            }
        },
        {
            "path": {
                "d": "m8 17 4 4 4-4"
            }
        }
    ]
}
