from .. import IconBase


class IconOctagonPause(IconBase):
    class_name = "lucide lucide-octagon-pause"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 15V9"
            }
        },
        {
            "path": {
                "d": "M14 15V9"
            }
        },
        {
            "path": {
                "d": "M7.714 2h8.572L22 7.714v8.572L16.286 22H7.714L2 16.286V7.714z"
            }
        }
    ]
}
