from .. import IconBase


class IconEraser(IconBase):
    class_name = "lucide lucide-eraser"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m7 21-4.3-4.3c-1-1-1-2.5 0-3.4l9.6-9.6c1-1 2.5-1 3.4 0l5.6 5.6c1 1 1 2.5 0 3.4L13 21"
            }
        },
        {
            "path": {
                "d": "M22 21H7"
            }
        },
        {
            "path": {
                "d": "m5 11 9 9"
            }
        }
    ]
}
