from .. import IconBase


class IconDumbbell(IconBase):
    class_name = "lucide lucide-dumbbell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m6.5 6.5 11 11"
            }
        },
        {
            "path": {
                "d": "m21 21-1-1"
            }
        },
        {
            "path": {
                "d": "m3 3 1 1"
            }
        },
        {
            "path": {
                "d": "m18 22 4-4"
            }
        },
        {
            "path": {
                "d": "m2 6 4-4"
            }
        },
        {
            "path": {
                "d": "m3 10 7-7"
            }
        },
        {
            "path": {
                "d": "m14 21 7-7"
            }
        }
    ]
}
