from .. import IconBase


class IconCone(IconBase):
    class_name = "lucide lucide-cone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m20.9 18.55-8-15.98a1 1 0 0 0-1.8 0l-8 15.98"
            }
        },
        {
            "ellipse": {
                "cx": "12",
                "cy": "19",
                "rx": "9",
                "ry": "3"
            }
        }
    ]
}
