from .. import IconBase


class IconGhost(IconBase):
    class_name = "lucide lucide-ghost"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M9 10h.01"
            }
        },
        {
            "path": {
                "d": "M15 10h.01"
            }
        },
        {
            "path": {
                "d": "M12 2a8 8 0 0 0-8 8v12l3-3 2.5 2.5L12 19l2.5 2.5L17 19l3 3V10a8 8 0 0 0-8-8z"
            }
        }
    ]
}
