from .. import IconBase


class IconGlassWater(IconBase):
    class_name = "lucide lucide-glass-water"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M15.2 22H8.8a2 2 0 0 1-2-1.79L5 3h14l-1.81 17.21A2 2 0 0 1 15.2 22Z"
            }
        },
        {
            "path": {
                "d": "M6 12a5 5 0 0 1 6 0 5 5 0 0 0 6 0"
            }
        }
    ]
}
