from .. import IconBase


class IconUtensils(IconBase):
    class_name = "lucide lucide-utensils"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 2v7c0 1.1.9 2 2 2h4a2 2 0 0 0 2-2V2"
            }
        },
        {
            "path": {
                "d": "M7 2v20"
            }
        },
        {
            "path": {
                "d": "M21 15V2v0a5 5 0 0 0-5 5v6c0 1.1.9 2 2 2h3Zm0 0v7"
            }
        }
    ]
}
