from .. import IconBase


class IconShoppingBag(IconBase):
    class_name = "lucide lucide-shopping-bag"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 2 3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6l-3-4Z"
            }
        },
        {
            "path": {
                "d": "M3 6h18"
            }
        },
        {
            "path": {
                "d": "M16 10a4 4 0 0 1-8 0"
            }
        }
    ]
}
