from .. import IconBase


class IconSignpostBig(IconBase):
    class_name = "lucide lucide-signpost-big"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 9H4L2 7l2-2h6"
            }
        },
        {
            "path": {
                "d": "M14 5h6l2 2-2 2h-6"
            }
        },
        {
            "path": {
                "d": "M10 22V4a2 2 0 1 1 4 0v18"
            }
        },
        {
            "path": {
                "d": "M8 22h8"
            }
        }
    ]
}
