from .. import IconBase


class IconConciergeBell(IconBase):
    class_name = "lucide lucide-concierge-bell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 20a1 1 0 0 1-1-1v-1a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1Z"
            }
        },
        {
            "path": {
                "d": "M20 16a8 8 0 1 0-16 0"
            }
        },
        {
            "path": {
                "d": "M12 4v4"
            }
        },
        {
            "path": {
                "d": "M10 4h4"
            }
        }
    ]
}
