from .. import IconBase


class IconPlug(IconBase):
    class_name = "lucide lucide-plug"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22v-5"
            }
        },
        {
            "path": {
                "d": "M9 8V2"
            }
        },
        {
            "path": {
                "d": "M15 8V2"
            }
        },
        {
            "path": {
                "d": "M18 8v5a4 4 0 0 1-4 4h-4a4 4 0 0 1-4-4V8Z"
            }
        }
    ]
}
