from .. import IconBase


class IconPlay(IconBase):
    class_name = "lucide lucide-play"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polygon": {
                "points": "6 3 20 12 6 21 6 3"
            }
        }
    ]
}
