from .. import IconBase


class IconWifi(IconBase):
    class_name = "lucide lucide-wifi"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 20h.01"
            }
        },
        {
            "path": {
                "d": "M2 8.82a15 15 0 0 1 20 0"
            }
        },
        {
            "path": {
                "d": "M5 12.859a10 10 0 0 1 14 0"
            }
        },
        {
            "path": {
                "d": "M8.5 16.429a5 5 0 0 1 7 0"
            }
        }
    ]
}
