from .. import IconBase


class IconCoins(IconBase):
    class_name = "lucide lucide-coins"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "8",
                "cy": "8",
                "r": "6"
            }
        },
        {
            "path": {
                "d": "M18.09 10.37A6 6 0 1 1 10.34 18"
            }
        },
        {
            "path": {
                "d": "M7 6h1v4"
            }
        },
        {
            "path": {
                "d": "m16.71 13.88.7.71-2.82 2.82"
            }
        }
    ]
}
