from .. import IconBase


class IconVegan(IconBase):
    class_name = "lucide lucide-vegan"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 2a26.6 26.6 0 0 1 10 20c.9-6.82 1.5-9.5 4-14"
            }
        },
        {
            "path": {
                "d": "M16 8c4 0 6-2 6-6-4 0-6 2-6 6"
            }
        },
        {
            "path": {
                "d": "M17.41 3.6a10 10 0 1 0 3 3"
            }
        }
    ]
}
