from .. import IconBase


class IconReceiptJapaneseYen(IconBase):
    class_name = "lucide lucide-receipt-japanese-yen"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z"
            }
        },
        {
            "path": {
                "d": "m12 10 3-3"
            }
        },
        {
            "path": {
                "d": "m9 7 3 3v7.5"
            }
        },
        {
            "path": {
                "d": "M9 11h6"
            }
        },
        {
            "path": {
                "d": "M9 15h6"
            }
        }
    ]
}
