from .. import IconBase


class IconTestTubeDiagonal(IconBase):
    class_name = "lucide lucide-test-tube-diagonal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 7 6.82 21.18a2.83 2.83 0 0 1-3.99-.01v0a2.83 2.83 0 0 1 0-4L17 3"
            }
        },
        {
            "path": {
                "d": "m16 2 6 6"
            }
        },
        {
            "path": {
                "d": "M12 16H4"
            }
        }
    ]
}
