from .. import IconBase


class IconBell(IconBase):
    class_name = "lucide lucide-bell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 8a6 6 0 0 1 12 0c0 7 3 9 3 9H3s3-2 3-9"
            }
        },
        {
            "path": {
                "d": "M10.3 21a1.94 1.94 0 0 0 3.4 0"
            }
        }
    ]
}
