from .. import IconBase


class IconNavigationOff(IconBase):
    class_name = "lucide lucide-navigation-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8.43 8.43 3 11l8 2 2 8 2.57-5.43"
            }
        },
        {
            "path": {
                "d": "M17.39 11.73 22 2l-9.73 4.61"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "22",
                "y1": "2",
                "y2": "22"
            }
        }
    ]
}
