from .. import IconBase


class IconGavel(IconBase):
    class_name = "lucide lucide-gavel"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m14.5 12.5-8 8a2.119 2.119 0 1 1-3-3l8-8"
            }
        },
        {
            "path": {
                "d": "m16 16 6-6"
            }
        },
        {
            "path": {
                "d": "m8 8 6-6"
            }
        },
        {
            "path": {
                "d": "m9 7 8 8"
            }
        },
        {
            "path": {
                "d": "m21 11-8-8"
            }
        }
    ]
}
