from .. import IconBase


class IconBookOpenCheck(IconBase):
    class_name = "lucide lucide-book-open-check"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 3H2v15h7c1.7 0 3 1.3 3 3V7c0-2.2-1.8-4-4-4Z"
            }
        },
        {
            "path": {
                "d": "m16 12 2 2 4-4"
            }
        },
        {
            "path": {
                "d": "M22 6V3h-6c-2.2 0-4 1.8-4 4v14c0-1.7 1.3-3 3-3h7v-2.3"
            }
        }
    ]
}
