from .. import IconBase


class IconRepeat(IconBase):
    class_name = "lucide lucide-repeat"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m17 2 4 4-4 4"
            }
        },
        {
            "path": {
                "d": "M3 11v-1a4 4 0 0 1 4-4h14"
            }
        },
        {
            "path": {
                "d": "m7 22-4-4 4-4"
            }
        },
        {
            "path": {
                "d": "M21 13v1a4 4 0 0 1-4 4H3"
            }
        }
    ]
}
