from .. import IconBase


class IconSquareArrowOutUpLeft(IconBase):
    class_name = "lucide lucide-square-arrow-out-up-left"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-6"
            }
        },
        {
            "path": {
                "d": "m3 3 9 9"
            }
        },
        {
            "path": {
                "d": "M3 9V3h6"
            }
        }
    ]
}
