from .. import IconBase


class IconMilestone(IconBase):
    class_name = "lucide lucide-milestone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 6H5a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h13l4-3.5L18 6Z"
            }
        },
        {
            "path": {
                "d": "M12 13v8"
            }
        },
        {
            "path": {
                "d": "M12 3v3"
            }
        }
    ]
}
