from .. import IconBase


class IconListMusic(IconBase):
    class_name = "lucide lucide-list-music"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 15V6"
            }
        },
        {
            "path": {
                "d": "M18.5 18a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5Z"
            }
        },
        {
            "path": {
                "d": "M12 12H3"
            }
        },
        {
            "path": {
                "d": "M16 6H3"
            }
        },
        {
            "path": {
                "d": "M12 18H3"
            }
        }
    ]
}
