from .. import IconBase


class IconArrowUp10(IconBase):
    class_name = "lucide lucide-arrow-up-1-0"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m3 8 4-4 4 4"
            }
        },
        {
            "path": {
                "d": "M7 4v16"
            }
        },
        {
            "path": {
                "d": "M17 10V4h-2"
            }
        },
        {
            "path": {
                "d": "M15 10h4"
            }
        },
        {
            "rect": {
                "x": "15",
                "y": "14",
                "width": "4",
                "height": "6",
                "ry": "2"
            }
        }
    ]
}
