from .. import IconBase


class IconIceCreamCone(IconBase):
    class_name = "lucide lucide-ice-cream-cone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m7 11 4.08 10.35a1 1 0 0 0 1.84 0L17 11"
            }
        },
        {
            "path": {
                "d": "M17 7A5 5 0 0 0 7 7"
            }
        },
        {
            "path": {
                "d": "M17 7a2 2 0 0 1 0 4H7a2 2 0 0 1 0-4"
            }
        }
    ]
}
