from .. import IconBase


class IconEuro(IconBase):
    class_name = "lucide lucide-euro"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 10h12"
            }
        },
        {
            "path": {
                "d": "M4 14h9"
            }
        },
        {
            "path": {
                "d": "M19 6a7.7 7.7 0 0 0-5.2-2A7.9 7.9 0 0 0 6 12c0 4.4 3.5 8 7.8 8 2 0 3.8-.8 5.2-2"
            }
        }
    ]
}
