from .. import IconBase


class IconUnfoldHorizontal(IconBase):
    class_name = "lucide lucide-unfold-horizontal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M16 12h6"
            }
        },
        {
            "path": {
                "d": "M8 12H2"
            }
        },
        {
            "path": {
                "d": "M12 2v2"
            }
        },
        {
            "path": {
                "d": "M12 8v2"
            }
        },
        {
            "path": {
                "d": "M12 14v2"
            }
        },
        {
            "path": {
                "d": "M12 20v2"
            }
        },
        {
            "path": {
                "d": "m19 15 3-3-3-3"
            }
        },
        {
            "path": {
                "d": "m5 9-3 3 3 3"
            }
        }
    ]
}
