from .. import IconBase


class IconFileSymlink(IconBase):
    class_name = "lucide lucide-file-symlink"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m10 18 3-3-3-3"
            }
        },
        {
            "path": {
                "d": "M14 2v4a2 2 0 0 0 2 2h4"
            }
        },
        {
            "path": {
                "d": "M4 11V4a2 2 0 0 1 2-2h9l5 5v13a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h7"
            }
        }
    ]
}
