from .. import IconBase


class IconPoundSterling(IconBase):
    class_name = "lucide lucide-pound-sterling"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 7c0-5.333-8-5.333-8 0"
            }
        },
        {
            "path": {
                "d": "M10 7v14"
            }
        },
        {
            "path": {
                "d": "M6 21h12"
            }
        },
        {
            "path": {
                "d": "M6 13h10"
            }
        }
    ]
}
