from .. import IconBase


class IconTouchpadOff(IconBase):
    class_name = "lucide lucide-touchpad-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h16"
            }
        },
        {
            "path": {
                "d": "M2 14h12"
            }
        },
        {
            "path": {
                "d": "M22 14h-2"
            }
        },
        {
            "path": {
                "d": "M12 20v-6"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        },
        {
            "path": {
                "d": "M22 16V6a2 2 0 0 0-2-2H10"
            }
        }
    ]
}
